@@ -74,8 +74,8 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
         :bool leaves_testing: True (uses all the leaf's evolutionary distances for training, it only observes (n-n_test) leafsequences. USE WITH n_test), False (uses all the leaf's evolutionary distances for training
                             and observes all the leaf sequences. Use with datasets without ancestors for testing, only generate sequences).
         """
-    BuildConfig = namedtuple('BuildConfig',['alignment_file','use_ancestral','n_test','build_graph',"aa_prob","triTSNE","leaves_testing","script_dir","no_testing"])
-    SettingsConfig = namedtuple("SettingsConfig", ["one_hot_encoding", "model_design", "aligned_seq","data_folder","full_name","tree_file"])
+    BuildConfig = namedtuple('BuildConfig',['alignment_file','use_ancestral','n_test','build_graph',"aa_prob","triTSNE","leaves_testing","script_dir","no_testing"],module="build_config") #__name__ + ".namespace"
+    SettingsConfig = namedtuple("SettingsConfig", ["one_hot_encoding", "model_design", "aligned_seq","data_folder","full_name","tree_file"],module="settings_config")
     if args.one_hot_encoded:
         warnings.warn("Draupnir was constructed to be used with integers for Categorical likelihood,not OneHotCategorical. And blosum-encoding for the guide. You can build"
                       "the one-hot-encoded dataset for other purposes")
@@ -111,8 +111,8 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
         if os.path.isdir(dir_name):
             if not os.listdir(dir_name):
                 print("Directory is empty")
-                #os.remove(dir_name)
                 #if download:
+                os.remove(dir_name)
                 print("Data directory is missing. Downloading, this might take a while. If you see an error like \n"
                       " 'Cannot retrieve the public link of the file. You may need to change the permission to <Anyone with the link>, or have had many accesses', \n"
                       "just wait, too many requests have been made to the google drive folder \n"
